==> linkedin-auto-bot-0.0.2.tgz: package/README.md <==
# LinkedIn Auto Connect Tool

Sometimes you want more `LinkedIn` connections, especially `500+`. This tool is very helpful to boost up your connections.
Just run it from your favorite terminal or command prompt and keep it running until you make enough connection requests.

> An automation tool to automate the connection requests on LinkedIn.

## Requirements

`node` >= `v4.0.0`

**Note**: If `node` and `npm` are not installed, Install them from [here](https://nodejs.org/en/download/).

## Installation

Install this tool using `npm`:

```bash
$ npm install -g linkedin-bot
```

It installs two binaries: `linkedin-bot` and `lac` to your system path.

## Usage

Use it as follows using `lac` command:

```bash
$ lab -u enter_your_linkedin_email> -k <keyword like Full Stack Developer>
Enter LinkedIn password: *****
```

***In the keyword argument, if you type "ALL" then this tool will send invitations request to the people you may know or else you can send the connect with the particular niche people like full stack developer, UI/UX, investors etc.***

If you want to keep your console clean, then just pass `--no-verbose` option.

**Note**: It does not share your `LinkedIn` credentials, so it is safe to use.

## Contributing

Your PRs and stars are always welcome.

Please, try to follow:

* Clone the repository.
* Checkout `develop` branch.
* Install dependencies.
* Add your new features or fixes.
* Build the project.
* Start the scraper.

```sh
$ git clone https://github.com/nomi9995/linkedin-bot.git
$ cd linkedin-bot
$ git checkout develop
$ npm i
$ npm run build
$ npm start
```

### Happy Hacking!

==> linkedin-auto-bot-0.0.3.tgz: package/README.md <==
# LinkedIn Auto Connect Tool

Sometimes you want more `LinkedIn` connections, especially `500+`. This tool is very helpful to boost up your connections.
Just run it from your favorite terminal or command prompt and keep it running until you make enough connection requests.

> An automation tool to automate the connection requests on LinkedIn.

## Requirements

`node` >= `v4.0.0`

**Note**: If `node` and `npm` are not installed, Install them from [here](https://nodejs.org/en/download/).

## Installation

Install this tool using `npm`:

```bash
$ npm install -g linkedin-auto-bot
```

It installs two binaries: `linkedin-auto-bot` and `lac` to your system path.

## Usage

Use it as follows using `lac` command:

```bash
$ lab -u enter_your_linkedin_email> -k <keyword like Full Stack Developer>
Enter LinkedIn password: *****
```

***In the keyword argument, if you type "ALL" then this tool will send invitations request to the people you may know or else you can send the connect with the particular niche people like full stack developer, UI/UX, investors etc.***

If you want to keep your console clean, then just pass `--no-verbose` option.

**Note**: It does not share your `LinkedIn` credentials, so it is safe to use.

## Contributing

Your PRs and stars are always welcome.

Please, try to follow:

* Clone the repository.
* Checkout `develop` branch.
* Install dependencies.
* Add your new features or fixes.
* Build the project.
* Start the scraper.

```sh
$ git clone https://github.com/nomi9995/linkedin-auto-bot.git
$ cd linkedin-auto-bot
$ git checkout develop
$ npm i
$ npm run build
$ npm start
```

### Happy Hacking!
